from django.conf import settings
import pytest

from ..constants import MIN_IMAGE_HEIGHT, MIN_IMAGE_WIDTH
from ..utils import create_test_image


@pytest.mark.django_db
def test_create_test_image(tmpdir):
    settings.MEDIA_ROOT = str(tmpdir)

    result = create_test_image(MIN_IMAGE_WIDTH, MIN_IMAGE_HEIGHT)

    assert result.width == MIN_IMAGE_WIDTH
    assert result.height == MIN_IMAGE_HEIGHT



from django.conf import settings
import pytest

from ..constants import MIN_IMAGE_HEIGHT, MIN_IMAGE_WIDTH
from ..exceptions import ImageTooSmall
from ..utils import create_test_image


@pytest.mark.django_db
class TestImageWithAttribution:

    def test_correctly_sized_image_saves(self, tmpdir):
        settings.MEDIA_ROOT = str(tmpdir)

        result = create_test_image(MIN_IMAGE_WIDTH, MIN_IMAGE_HEIGHT)

        assert result.id
        assert result.width == MIN_IMAGE_WIDTH
        assert result.height == MIN_IMAGE_HEIGHT

    def test_incorrectly_sized_image_raises(self, tmpdir):
        settings.MEDIA_ROOT = str(tmpdir)

        with pytest.raises(ImageTooSmall):
            create_test_image(MIN_IMAGE_WIDTH - 1, MIN_IMAGE_HEIGHT - 1)



from io import BytesIO

from django.core.files.images import ImageFile
from PIL import Image

from .models import ImageWithAttribution


def create_test_image(width=500, height=500):
    binary_stream = BytesIO()

    file_name = 'test_image.png'

    image = Image.new('RGB', (width, height), 'white')
    image.save(binary_stream, 'PNG')
    image_file = ImageFile(
        binary_stream,
        name=file_name
    )

    model_image = ImageWithAttribution(
        title=file_name,
        file=image_file
    )
    model_image.save()

    return model_image



from .constants import MIN_IMAGE_HEIGHT, MIN_IMAGE_WIDTH


class ImageTooSmall(Exception):

    def __init__(self, image):
        self.image = image
        self.message = ('{0} is too small ({1} x {2}).'
                        'It should be a minimum of {3} x {4}').format(
                            image.file, image.width, image.height,
                            MIN_IMAGE_WIDTH, MIN_IMAGE_HEIGHT
        )
